pub struct DaemonAsync {
pub sender: Arc<Sender<All>>,
pub state: Arc<DaemonState>,
}Expand description
Represents a blockchain node.
It’s constructed using DaemonAsyncBuilder.
Usage
use cw_orch_daemon::{DaemonAsync, networks};
let daemon: DaemonAsync = DaemonAsync::builder()
.chain(networks::JUNO_1)
.build()
.await.unwrap();Environment Execution
The DaemonAsync implements async methods of TxHandler which allows you to perform transactions on the chain.
Querying
Different Cosmos SDK modules can be queried through the daemon by calling the [DaemonAsync::query_client<Querier>] method with a specific querier.
See Querier for examples.
Warning
This daemon is thread safe and can be used between threads. However, please make sure that you are not trying to broadcast multiple transactions at once when using this Daemon on different threads. If you do so, you WILL get account sequence errors and your transactions won’t get broadcasted. Use a Mutex on top of this DaemonAsync to avoid such errors.
Fields
sender: Arc<Sender<All>>Sender to send transactions to the chain
state: Arc<DaemonState>State of the daemon
Implementations
Sourceimpl DaemonAsync
impl DaemonAsync
Sourceimpl DaemonAsync
impl DaemonAsync
Sourcepub fn rebuild(&self) -> DaemonAsyncBuilder
pub fn rebuild(&self) -> DaemonAsyncBuilder
Returns a new DaemonAsyncBuilder with the current configuration.
Does not consume the original DaemonAsync.
Sourcepub async fn execute<E>(
&self,
exec_msg: &E,
coins: &[Coin],
contract_address: &Addr,
) -> Result<CosmTxResponse, DaemonError>where
E: Serialize,
pub async fn execute<E>(
&self,
exec_msg: &E,
coins: &[Coin],
contract_address: &Addr,
) -> Result<CosmTxResponse, DaemonError>where
E: Serialize,
Execute a message on a contract.
Sourcepub async fn instantiate<I>(
&self,
code_id: u64,
init_msg: &I,
label: Option<&str>,
admin: Option<&Addr>,
coins: &[Coin],
) -> Result<CosmTxResponse, DaemonError>
pub async fn instantiate<I>( &self, code_id: u64, init_msg: &I, label: Option<&str>, admin: Option<&Addr>, coins: &[Coin], ) -> Result<CosmTxResponse, DaemonError>
Instantiate a contract.
Sourcepub async fn instantiate2<I>(
&self,
code_id: u64,
init_msg: &I,
label: Option<&str>,
admin: Option<&Addr>,
coins: &[Coin],
salt: Binary,
) -> Result<CosmTxResponse, DaemonError>
pub async fn instantiate2<I>( &self, code_id: u64, init_msg: &I, label: Option<&str>, admin: Option<&Addr>, coins: &[Coin], salt: Binary, ) -> Result<CosmTxResponse, DaemonError>
Instantiate a contract.
Sourcepub async fn query<Q, T>(
&self,
query_msg: &Q,
contract_address: &Addr,
) -> Result<T, DaemonError>
pub async fn query<Q, T>( &self, query_msg: &Q, contract_address: &Addr, ) -> Result<T, DaemonError>
Query a contract.
Sourcepub async fn migrate<M>(
&self,
migrate_msg: &M,
new_code_id: u64,
contract_address: &Addr,
) -> Result<CosmTxResponse, DaemonError>
pub async fn migrate<M>( &self, migrate_msg: &M, new_code_id: u64, contract_address: &Addr, ) -> Result<CosmTxResponse, DaemonError>
Migration a contract.
Sourcepub async fn wait_blocks(&self, amount: u64) -> Result<(), DaemonError>
pub async fn wait_blocks(&self, amount: u64) -> Result<(), DaemonError>
Wait for a given amount of blocks.
Sourcepub async fn wait_seconds(&self, secs: u64) -> Result<(), DaemonError>
pub async fn wait_seconds(&self, secs: u64) -> Result<(), DaemonError>
Wait for a given amount of seconds.
Sourcepub async fn next_block(&self) -> Result<(), DaemonError>
pub async fn next_block(&self) -> Result<(), DaemonError>
Wait for the next block.
Sourcepub async fn block_info(&self) -> Result<BlockInfo, DaemonError>
pub async fn block_info(&self) -> Result<BlockInfo, DaemonError>
Get the current block info.
Sourcepub async fn upload<T>(
&self,
_uploadable: &T,
) -> Result<CosmTxResponse, DaemonError>where
T: Uploadable,
pub async fn upload<T>(
&self,
_uploadable: &T,
) -> Result<CosmTxResponse, DaemonError>where
T: Uploadable,
Upload a contract to the chain.
Sourcepub fn set_sender(&mut self, sender: &Arc<Sender<All>>)
pub fn set_sender(&mut self, sender: &Arc<Sender<All>>)
Set the sender to use with this DaemonAsync to be the given wallet